# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.application_summary_status import ApplicationSummaryStatus  # noqa: E501
from agilicus_api.rest import ApiException

class TestApplicationSummaryStatus(unittest.TestCase):
    """ApplicationSummaryStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ApplicationSummaryStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.application_summary_status.ApplicationSummaryStatus()  # noqa: E501
        if include_optional :
            return ApplicationSummaryStatus(
                application_id = '39dl4dDJGdjgud8', 
                application_name = 'parking', 
                assigned_org_id = 'as9f9adfDFwEE9', 
                published = 'no', 
                description = 'An application to submit parking requests', 
                category = 'citizen-facing', 
                icon_url = 'https://storage.googleapis.com/agilicus/logo.svg', 
                default_role_name = 'self', 
                default_role_id = 'as0Z6fXFsl23'
            )
        else :
            return ApplicationSummaryStatus(
                application_id = '39dl4dDJGdjgud8',
                application_name = 'parking',
                assigned_org_id = 'as9f9adfDFwEE9',
                published = 'no',
                icon_url = 'https://storage.googleapis.com/agilicus/logo.svg',
        )

    def testApplicationSummaryStatus(self):
        """Test ApplicationSummaryStatus"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.mfa_challenge_question_login_info import MFAChallengeQuestionLoginInfo  # noqa: E501
from agilicus_api.rest import ApiException

class TestMFAChallengeQuestionLoginInfo(unittest.TestCase):
    """MFAChallengeQuestionLoginInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MFAChallengeQuestionLoginInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.mfa_challenge_question_login_info.MFAChallengeQuestionLoginInfo()  # noqa: E501
        if include_optional :
            return MFAChallengeQuestionLoginInfo(
                user_preference = 'organisation_policy', 
                client_id = 'app-1', 
                client_guid = 'absjfladasdf23', 
                issuer_org_id = 'absjfladasdf23', 
                issuer_guid = 'absjfladasdf23', 
                org_id = 'absjfladasdf23', 
                user_id = 'jjkkGmwB9oTJWDjIglTU', 
                user_object = agilicus_api.models.user_summary.UserSummary(
                    id = '123', 
                    external_id = '123', 
                    enabled = False, 
                    status = 'active', 
                    first_name = 'Alice', 
                    last_name = 'Kim', 
                    email = 'foo@example.com', 
                    provider = 'Google', 
                    roles = {"app-1":["viewer"],"app-2":["owner"]}, 
                    org_id = '123', 
                    created = '2015-07-07T15:49:51.230+02:00', 
                    updated = '2015-07-07T15:49:51.230+02:00', 
                    auto_created = True, 
                    upstream_user_identities = [
                        agilicus_api.models.upstream_user_identity.UpstreamUserIdentity(
                            metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                            spec = agilicus_api.models.upstream_user_identity_spec.UpstreamUserIdentitySpec(
                                upstream_user_id = 'aa-bb-cc-11-22-33', 
                                upstream_idp_id = 'https://auth.cloud.egov.city', 
                                local_user_id = 'tuU7smH86zAXMl76sua6xQ', ), )
                        ], 
                    cascade = True, ), 
                upstream_idp = 'city-adfs', 
                ip_address = '127.0.0.1', 
                amr_claim_present = True, 
                last_mfa_login = '2015-07-07T15:49:51.230+02:00', 
                user_mfa_preferences = [
                    agilicus_api.models.mfa_challenge_method.MFAChallengeMethod(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.mfa_challenge_method_spec.MFAChallengeMethodSpec(
                            priority = 1, 
                            challenge_type = '0', 
                            endpoint = '0', 
                            origin = 'agilicus.cloud', 
                            nickname = '0', 
                            enabled = True, ), )
                    ]
            )
        else :
            return MFAChallengeQuestionLoginInfo(
                user_preference = 'organisation_policy',
                client_id = 'app-1',
                client_guid = 'absjfladasdf23',
                issuer_org_id = 'absjfladasdf23',
                issuer_guid = 'absjfladasdf23',
                org_id = 'absjfladasdf23',
                user_id = 'jjkkGmwB9oTJWDjIglTU',
                upstream_idp = 'city-adfs',
                ip_address = '127.0.0.1',
                amr_claim_present = True,
        )

    def testMFAChallengeQuestionLoginInfo(self):
        """Test MFAChallengeQuestionLoginInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class OIDCProxyDomainMapping(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'primary_external_name': 'str',
        'primary_internal_name': 'str',
        'other_mappings': 'list[OIDCProxyDomainNameMapping]'
    }

    attribute_map = {
        'primary_external_name': 'primary_external_name',
        'primary_internal_name': 'primary_internal_name',
        'other_mappings': 'other_mappings'
    }

    def __init__(self, primary_external_name=None, primary_internal_name=None, other_mappings=None, local_vars_configuration=None):  # noqa: E501
        """OIDCProxyDomainMapping - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._primary_external_name = None
        self._primary_internal_name = None
        self._other_mappings = None
        self.discriminator = None

        self.primary_external_name = primary_external_name
        self.primary_internal_name = primary_internal_name
        if other_mappings is not None:
            self.other_mappings = other_mappings

    @property
    def primary_external_name(self):
        """Gets the primary_external_name of this OIDCProxyDomainMapping.  # noqa: E501

        The primary external name is the name that gets exposed publicly.  # noqa: E501

        :return: The primary_external_name of this OIDCProxyDomainMapping.  # noqa: E501
        :rtype: str
        """
        return self._primary_external_name

    @primary_external_name.setter
    def primary_external_name(self, primary_external_name):
        """Sets the primary_external_name of this OIDCProxyDomainMapping.

        The primary external name is the name that gets exposed publicly.  # noqa: E501

        :param primary_external_name: The primary_external_name of this OIDCProxyDomainMapping.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and primary_external_name is None:  # noqa: E501
            raise ValueError("Invalid value for `primary_external_name`, must not be `None`")  # noqa: E501

        self._primary_external_name = primary_external_name

    @property
    def primary_internal_name(self):
        """Gets the primary_internal_name of this OIDCProxyDomainMapping.  # noqa: E501

        The primary internal name is the name that used internally in the local environment.  # noqa: E501

        :return: The primary_internal_name of this OIDCProxyDomainMapping.  # noqa: E501
        :rtype: str
        """
        return self._primary_internal_name

    @primary_internal_name.setter
    def primary_internal_name(self, primary_internal_name):
        """Sets the primary_internal_name of this OIDCProxyDomainMapping.

        The primary internal name is the name that used internally in the local environment.  # noqa: E501

        :param primary_internal_name: The primary_internal_name of this OIDCProxyDomainMapping.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and primary_internal_name is None:  # noqa: E501
            raise ValueError("Invalid value for `primary_internal_name`, must not be `None`")  # noqa: E501

        self._primary_internal_name = primary_internal_name

    @property
    def other_mappings(self):
        """Gets the other_mappings of this OIDCProxyDomainMapping.  # noqa: E501

        The list of extra mappings between internal and external domain names.  # noqa: E501

        :return: The other_mappings of this OIDCProxyDomainMapping.  # noqa: E501
        :rtype: list[OIDCProxyDomainNameMapping]
        """
        return self._other_mappings

    @other_mappings.setter
    def other_mappings(self, other_mappings):
        """Sets the other_mappings of this OIDCProxyDomainMapping.

        The list of extra mappings between internal and external domain names.  # noqa: E501

        :param other_mappings: The other_mappings of this OIDCProxyDomainMapping.  # noqa: E501
        :type: list[OIDCProxyDomainNameMapping]
        """

        self._other_mappings = other_mappings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OIDCProxyDomainMapping):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OIDCProxyDomainMapping):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class CatalogueEntry(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'catalogue_id': 'str',
        'catalogue_category': 'str',
        'name': 'str',
        'content': 'str',
        'tag': 'str',
        'short_description': 'str',
        'long_description': 'str',
        'created': 'datetime',
        'updated': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'catalogue_id': 'catalogue_id',
        'catalogue_category': 'catalogue_category',
        'name': 'name',
        'content': 'content',
        'tag': 'tag',
        'short_description': 'short_description',
        'long_description': 'long_description',
        'created': 'created',
        'updated': 'updated'
    }

    def __init__(self, id=None, catalogue_id=None, catalogue_category=None, name=None, content=None, tag=None, short_description=None, long_description=None, created=None, updated=None, local_vars_configuration=None):  # noqa: E501
        """CatalogueEntry - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._catalogue_id = None
        self._catalogue_category = None
        self._name = None
        self._content = None
        self._tag = None
        self._short_description = None
        self._long_description = None
        self._created = None
        self._updated = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if catalogue_id is not None:
            self.catalogue_id = catalogue_id
        if catalogue_category is not None:
            self.catalogue_category = catalogue_category
        self.name = name
        if content is not None:
            self.content = content
        if tag is not None:
            self.tag = tag
        if short_description is not None:
            self.short_description = short_description
        if long_description is not None:
            self.long_description = long_description
        if created is not None:
            self.created = created
        if updated is not None:
            self.updated = updated

    @property
    def id(self):
        """Gets the id of this CatalogueEntry.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The id of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CatalogueEntry.

        Unique identifier  # noqa: E501

        :param id: The id of this CatalogueEntry.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def catalogue_id(self):
        """Gets the catalogue_id of this CatalogueEntry.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The catalogue_id of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._catalogue_id

    @catalogue_id.setter
    def catalogue_id(self, catalogue_id):
        """Sets the catalogue_id of this CatalogueEntry.

        Unique identifier  # noqa: E501

        :param catalogue_id: The catalogue_id of this CatalogueEntry.  # noqa: E501
        :type: str
        """

        self._catalogue_id = catalogue_id

    @property
    def catalogue_category(self):
        """Gets the catalogue_category of this CatalogueEntry.  # noqa: E501

        The category of catalogue that this entry is apart of  # noqa: E501

        :return: The catalogue_category of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._catalogue_category

    @catalogue_category.setter
    def catalogue_category(self, catalogue_category):
        """Sets the catalogue_category of this CatalogueEntry.

        The category of catalogue that this entry is apart of  # noqa: E501

        :param catalogue_category: The catalogue_category of this CatalogueEntry.  # noqa: E501
        :type: str
        """

        self._catalogue_category = catalogue_category

    @property
    def name(self):
        """Gets the name of this CatalogueEntry.  # noqa: E501

        The name of the catalogue entry in a user friendly form  # noqa: E501

        :return: The name of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CatalogueEntry.

        The name of the catalogue entry in a user friendly form  # noqa: E501

        :param name: The name of this CatalogueEntry.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501

        self._name = name

    @property
    def content(self):
        """Gets the content of this CatalogueEntry.  # noqa: E501

        The content of the catalogue  # noqa: E501

        :return: The content of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this CatalogueEntry.

        The content of the catalogue  # noqa: E501

        :param content: The content of this CatalogueEntry.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                content is not None and len(content) > 5242880):
            raise ValueError("Invalid value for `content`, length must be less than or equal to `5242880`")  # noqa: E501

        self._content = content

    @property
    def tag(self):
        """Gets the tag of this CatalogueEntry.  # noqa: E501

        A qualifier for the catalogue entry. Used for differentiating between entries of the same name  # noqa: E501

        :return: The tag of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this CatalogueEntry.

        A qualifier for the catalogue entry. Used for differentiating between entries of the same name  # noqa: E501

        :param tag: The tag of this CatalogueEntry.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                tag is not None and len(tag) > 40):
            raise ValueError("Invalid value for `tag`, length must be less than or equal to `40`")  # noqa: E501

        self._tag = tag

    @property
    def short_description(self):
        """Gets the short_description of this CatalogueEntry.  # noqa: E501

        A short description of the catalogue entry.  # noqa: E501

        :return: The short_description of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """Sets the short_description of this CatalogueEntry.

        A short description of the catalogue entry.  # noqa: E501

        :param short_description: The short_description of this CatalogueEntry.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                short_description is not None and len(short_description) > 255):
            raise ValueError("Invalid value for `short_description`, length must be less than or equal to `255`")  # noqa: E501

        self._short_description = short_description

    @property
    def long_description(self):
        """Gets the long_description of this CatalogueEntry.  # noqa: E501

        A detailed description of the catalogue entry  # noqa: E501

        :return: The long_description of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._long_description

    @long_description.setter
    def long_description(self, long_description):
        """Sets the long_description of this CatalogueEntry.

        A detailed description of the catalogue entry  # noqa: E501

        :param long_description: The long_description of this CatalogueEntry.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                long_description is not None and len(long_description) > 2000):
            raise ValueError("Invalid value for `long_description`, length must be less than or equal to `2000`")  # noqa: E501

        self._long_description = long_description

    @property
    def created(self):
        """Gets the created of this CatalogueEntry.  # noqa: E501

        Creation time  # noqa: E501

        :return: The created of this CatalogueEntry.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this CatalogueEntry.

        Creation time  # noqa: E501

        :param created: The created of this CatalogueEntry.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this CatalogueEntry.  # noqa: E501

        Update time  # noqa: E501

        :return: The updated of this CatalogueEntry.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this CatalogueEntry.

        Update time  # noqa: E501

        :param updated: The updated of this CatalogueEntry.  # noqa: E501
        :type: datetime
        """

        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CatalogueEntry):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CatalogueEntry):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class Organisation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'all_users_group_id': 'str',
        'all_users_all_suborgs_group_id': 'str',
        'all_users_direct_suborgs_group_id': 'str',
        'auto_created_users_group_id': 'str',
        'external_id': 'str',
        'organisation': 'str',
        'issuer': 'str',
        'issuer_id': 'str',
        'subdomain': 'str',
        'created': 'datetime',
        'updated': 'datetime',
        'contact_id': 'str',
        'contact_email': 'str',
        'parent_id': 'str',
        'root_org_id': 'str',
        'auto_create': 'bool',
        'trust_on_first_use_duration': 'int',
        'feature_flags': 'list[FeatureFlag]',
        'admin_state': 'OrganisationStateSelector',
        'status': 'OrganisationStatus'
    }

    attribute_map = {
        'id': 'id',
        'all_users_group_id': 'all_users_group_id',
        'all_users_all_suborgs_group_id': 'all_users_all_suborgs_group_id',
        'all_users_direct_suborgs_group_id': 'all_users_direct_suborgs_group_id',
        'auto_created_users_group_id': 'auto_created_users_group_id',
        'external_id': 'external_id',
        'organisation': 'organisation',
        'issuer': 'issuer',
        'issuer_id': 'issuer_id',
        'subdomain': 'subdomain',
        'created': 'created',
        'updated': 'updated',
        'contact_id': 'contact_id',
        'contact_email': 'contact_email',
        'parent_id': 'parent_id',
        'root_org_id': 'root_org_id',
        'auto_create': 'auto_create',
        'trust_on_first_use_duration': 'trust_on_first_use_duration',
        'feature_flags': 'feature_flags',
        'admin_state': 'admin_state',
        'status': 'status'
    }

    def __init__(self, id=None, all_users_group_id=None, all_users_all_suborgs_group_id=None, all_users_direct_suborgs_group_id=None, auto_created_users_group_id=None, external_id=None, organisation=None, issuer=None, issuer_id=None, subdomain=None, created=None, updated=None, contact_id=None, contact_email=None, parent_id=None, root_org_id=None, auto_create=False, trust_on_first_use_duration=86400, feature_flags=None, admin_state=None, status=None, local_vars_configuration=None):  # noqa: E501
        """Organisation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._all_users_group_id = None
        self._all_users_all_suborgs_group_id = None
        self._all_users_direct_suborgs_group_id = None
        self._auto_created_users_group_id = None
        self._external_id = None
        self._organisation = None
        self._issuer = None
        self._issuer_id = None
        self._subdomain = None
        self._created = None
        self._updated = None
        self._contact_id = None
        self._contact_email = None
        self._parent_id = None
        self._root_org_id = None
        self._auto_create = None
        self._trust_on_first_use_duration = None
        self._feature_flags = None
        self._admin_state = None
        self._status = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if all_users_group_id is not None:
            self.all_users_group_id = all_users_group_id
        if all_users_all_suborgs_group_id is not None:
            self.all_users_all_suborgs_group_id = all_users_all_suborgs_group_id
        if all_users_direct_suborgs_group_id is not None:
            self.all_users_direct_suborgs_group_id = all_users_direct_suborgs_group_id
        if auto_created_users_group_id is not None:
            self.auto_created_users_group_id = auto_created_users_group_id
        if external_id is not None:
            self.external_id = external_id
        if organisation is not None:
            self.organisation = organisation
        if issuer is not None:
            self.issuer = issuer
        if issuer_id is not None:
            self.issuer_id = issuer_id
        if subdomain is not None:
            self.subdomain = subdomain
        if created is not None:
            self.created = created
        if updated is not None:
            self.updated = updated
        if contact_id is not None:
            self.contact_id = contact_id
        if contact_email is not None:
            self.contact_email = contact_email
        if parent_id is not None:
            self.parent_id = parent_id
        if root_org_id is not None:
            self.root_org_id = root_org_id
        if auto_create is not None:
            self.auto_create = auto_create
        if trust_on_first_use_duration is not None:
            self.trust_on_first_use_duration = trust_on_first_use_duration
        if feature_flags is not None:
            self.feature_flags = feature_flags
        if admin_state is not None:
            self.admin_state = admin_state
        if status is not None:
            self.status = status

    @property
    def id(self):
        """Gets the id of this Organisation.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The id of this Organisation.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Organisation.

        Unique identifier  # noqa: E501

        :param id: The id of this Organisation.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def all_users_group_id(self):
        """Gets the all_users_group_id of this Organisation.  # noqa: E501

        group id of group containing this organisations all users  # noqa: E501

        :return: The all_users_group_id of this Organisation.  # noqa: E501
        :rtype: str
        """
        return self._all_users_group_id

    @all_users_group_id.setter
    def all_users_group_id(self, all_users_group_id):
        """Sets the all_users_group_id of this Organisation.

        group id of group containing this organisations all users  # noqa: E501

        :param all_users_group_id: The all_users_group_id of this Organisation.  # noqa: E501
        :type: str
        """

        self._all_users_group_id = all_users_group_id

    @property
    def all_users_all_suborgs_group_id(self):
        """Gets the all_users_all_suborgs_group_id of this Organisation.  # noqa: E501

        group id of group containing this organisations all users including all sub organisations  # noqa: E501

        :return: The all_users_all_suborgs_group_id of this Organisation.  # noqa: E501
        :rtype: str
        """
        return self._all_users_all_suborgs_group_id

    @all_users_all_suborgs_group_id.setter
    def all_users_all_suborgs_group_id(self, all_users_all_suborgs_group_id):
        """Sets the all_users_all_suborgs_group_id of this Organisation.

        group id of group containing this organisations all users including all sub organisations  # noqa: E501

        :param all_users_all_suborgs_group_id: The all_users_all_suborgs_group_id of this Organisation.  # noqa: E501
        :type: str
        """

        self._all_users_all_suborgs_group_id = all_users_all_suborgs_group_id

    @property
    def all_users_direct_suborgs_group_id(self):
        """Gets the all_users_direct_suborgs_group_id of this Organisation.  # noqa: E501

        group id of group containing this organisations all users including only direct sub organisations  # noqa: E501

        :return: The all_users_direct_suborgs_group_id of this Organisation.  # noqa: E501
        :rtype: str
        """
        return self._all_users_direct_suborgs_group_id

    @all_users_direct_suborgs_group_id.setter
    def all_users_direct_suborgs_group_id(self, all_users_direct_suborgs_group_id):
        """Sets the all_users_direct_suborgs_group_id of this Organisation.

        group id of group containing this organisations all users including only direct sub organisations  # noqa: E501

        :param all_users_direct_suborgs_group_id: The all_users_direct_suborgs_group_id of this Organisation.  # noqa: E501
        :type: str
        """

        self._all_users_direct_suborgs_group_id = all_users_direct_suborgs_group_id

    @property
    def auto_created_users_group_id(self):
        """Gets the auto_created_users_group_id of this Organisation.  # noqa: E501

        group id of group containing users automatically created when they logged in  # noqa: E501

        :return: The auto_created_users_group_id of this Organisation.  # noqa: E501
        :rtype: str
        """
        return self._auto_created_users_group_id

    @auto_created_users_group_id.setter
    def auto_created_users_group_id(self, auto_created_users_group_id):
        """Sets the auto_created_users_group_id of this Organisation.

        group id of group containing users automatically created when they logged in  # noqa: E501

        :param auto_created_users_group_id: The auto_created_users_group_id of this Organisation.  # noqa: E501
        :type: str
        """

        self._auto_created_users_group_id = auto_created_users_group_id

    @property
    def external_id(self):
        """Gets the external_id of this Organisation.  # noqa: E501

        External unique identifier  # noqa: E501

        :return: The external_id of this Organisation.  # noqa: E501
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this Organisation.

        External unique identifier  # noqa: E501

        :param external_id: The external_id of this Organisation.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                external_id is not None and len(external_id) > 100):
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `100`")  # noqa: E501

        self._external_id = external_id

    @property
    def organisation(self):
        """Gets the organisation of this Organisation.  # noqa: E501

        organisation name  # noqa: E501

        :return: The organisation of this Organisation.  # noqa: E501
        :rtype: str
        """
        return self._organisation

    @organisation.setter
    def organisation(self, organisation):
        """Sets the organisation of this Organisation.

        organisation name  # noqa: E501

        :param organisation: The organisation of this Organisation.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                organisation is not None and len(organisation) > 100):
            raise ValueError("Invalid value for `organisation`, length must be less than or equal to `100`")  # noqa: E501

        self._organisation = organisation

    @property
    def issuer(self):
        """Gets the issuer of this Organisation.  # noqa: E501

        connect id issuer  # noqa: E501

        :return: The issuer of this Organisation.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this Organisation.

        connect id issuer  # noqa: E501

        :param issuer: The issuer of this Organisation.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                issuer is not None and len(issuer) > 100):
            raise ValueError("Invalid value for `issuer`, length must be less than or equal to `100`")  # noqa: E501

        self._issuer = issuer

    @property
    def issuer_id(self):
        """Gets the issuer_id of this Organisation.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The issuer_id of this Organisation.  # noqa: E501
        :rtype: str
        """
        return self._issuer_id

    @issuer_id.setter
    def issuer_id(self, issuer_id):
        """Sets the issuer_id of this Organisation.

        Unique identifier  # noqa: E501

        :param issuer_id: The issuer_id of this Organisation.  # noqa: E501
        :type: str
        """

        self._issuer_id = issuer_id

    @property
    def subdomain(self):
        """Gets the subdomain of this Organisation.  # noqa: E501

        Organisations subdomain. Note this must be unique accross all organisations  # noqa: E501

        :return: The subdomain of this Organisation.  # noqa: E501
        :rtype: str
        """
        return self._subdomain

    @subdomain.setter
    def subdomain(self, subdomain):
        """Sets the subdomain of this Organisation.

        Organisations subdomain. Note this must be unique accross all organisations  # noqa: E501

        :param subdomain: The subdomain of this Organisation.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                subdomain is not None and len(subdomain) > 100):
            raise ValueError("Invalid value for `subdomain`, length must be less than or equal to `100`")  # noqa: E501

        self._subdomain = subdomain

    @property
    def created(self):
        """Gets the created of this Organisation.  # noqa: E501

        Creation time  # noqa: E501

        :return: The created of this Organisation.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Organisation.

        Creation time  # noqa: E501

        :param created: The created of this Organisation.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this Organisation.  # noqa: E501

        Update time  # noqa: E501

        :return: The updated of this Organisation.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this Organisation.

        Update time  # noqa: E501

        :param updated: The updated of this Organisation.  # noqa: E501
        :type: datetime
        """

        self._updated = updated

    @property
    def contact_id(self):
        """Gets the contact_id of this Organisation.  # noqa: E501

        GUID of the organisation admin  # noqa: E501

        :return: The contact_id of this Organisation.  # noqa: E501
        :rtype: str
        """
        return self._contact_id

    @contact_id.setter
    def contact_id(self, contact_id):
        """Sets the contact_id of this Organisation.

        GUID of the organisation admin  # noqa: E501

        :param contact_id: The contact_id of this Organisation.  # noqa: E501
        :type: str
        """

        self._contact_id = contact_id

    @property
    def contact_email(self):
        """Gets the contact_email of this Organisation.  # noqa: E501

        The email address of the contact.  # noqa: E501

        :return: The contact_email of this Organisation.  # noqa: E501
        :rtype: str
        """
        return self._contact_email

    @contact_email.setter
    def contact_email(self, contact_email):
        """Sets the contact_email of this Organisation.

        The email address of the contact.  # noqa: E501

        :param contact_email: The contact_email of this Organisation.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                contact_email is not None and len(contact_email) > 100):
            raise ValueError("Invalid value for `contact_email`, length must be less than or equal to `100`")  # noqa: E501

        self._contact_email = contact_email

    @property
    def parent_id(self):
        """Gets the parent_id of this Organisation.  # noqa: E501

        parent organisation id  # noqa: E501

        :return: The parent_id of this Organisation.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this Organisation.

        parent organisation id  # noqa: E501

        :param parent_id: The parent_id of this Organisation.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def root_org_id(self):
        """Gets the root_org_id of this Organisation.  # noqa: E501

        The id of the organisation at the root of this organisation hierarchy. For example, if A is the parent of B, and B is the parent of C, then A would be the root organisation of A, B and C. Note that this field will be ignored if changed.   # noqa: E501

        :return: The root_org_id of this Organisation.  # noqa: E501
        :rtype: str
        """
        return self._root_org_id

    @root_org_id.setter
    def root_org_id(self, root_org_id):
        """Sets the root_org_id of this Organisation.

        The id of the organisation at the root of this organisation hierarchy. For example, if A is the parent of B, and B is the parent of C, then A would be the root organisation of A, B and C. Note that this field will be ignored if changed.   # noqa: E501

        :param root_org_id: The root_org_id of this Organisation.  # noqa: E501
        :type: str
        """

        self._root_org_id = root_org_id

    @property
    def auto_create(self):
        """Gets the auto_create of this Organisation.  # noqa: E501

        Auto-creates a user  # noqa: E501

        :return: The auto_create of this Organisation.  # noqa: E501
        :rtype: bool
        """
        return self._auto_create

    @auto_create.setter
    def auto_create(self, auto_create):
        """Sets the auto_create of this Organisation.

        Auto-creates a user  # noqa: E501

        :param auto_create: The auto_create of this Organisation.  # noqa: E501
        :type: bool
        """

        self._auto_create = auto_create

    @property
    def trust_on_first_use_duration(self):
        """Gets the trust_on_first_use_duration of this Organisation.  # noqa: E501

        The time window in seconds which represents the period of time for which a new user is eligible for trust on first use enrollment. The duration will be applied from the user's created date, or if the user's enrollment period was reset by an administrator.   # noqa: E501

        :return: The trust_on_first_use_duration of this Organisation.  # noqa: E501
        :rtype: int
        """
        return self._trust_on_first_use_duration

    @trust_on_first_use_duration.setter
    def trust_on_first_use_duration(self, trust_on_first_use_duration):
        """Sets the trust_on_first_use_duration of this Organisation.

        The time window in seconds which represents the period of time for which a new user is eligible for trust on first use enrollment. The duration will be applied from the user's created date, or if the user's enrollment period was reset by an administrator.   # noqa: E501

        :param trust_on_first_use_duration: The trust_on_first_use_duration of this Organisation.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                trust_on_first_use_duration is not None and trust_on_first_use_duration < 0):  # noqa: E501
            raise ValueError("Invalid value for `trust_on_first_use_duration`, must be a value greater than or equal to `0`")  # noqa: E501

        self._trust_on_first_use_duration = trust_on_first_use_duration

    @property
    def feature_flags(self):
        """Gets the feature_flags of this Organisation.  # noqa: E501

        A list of features to enable or disable. This is mostly for advanced use. No guarantees exist that a given feature will always exist by a given name, or that it will be configurable.   # noqa: E501

        :return: The feature_flags of this Organisation.  # noqa: E501
        :rtype: list[FeatureFlag]
        """
        return self._feature_flags

    @feature_flags.setter
    def feature_flags(self, feature_flags):
        """Sets the feature_flags of this Organisation.

        A list of features to enable or disable. This is mostly for advanced use. No guarantees exist that a given feature will always exist by a given name, or that it will be configurable.   # noqa: E501

        :param feature_flags: The feature_flags of this Organisation.  # noqa: E501
        :type: list[FeatureFlag]
        """

        self._feature_flags = feature_flags

    @property
    def admin_state(self):
        """Gets the admin_state of this Organisation.  # noqa: E501


        :return: The admin_state of this Organisation.  # noqa: E501
        :rtype: OrganisationStateSelector
        """
        return self._admin_state

    @admin_state.setter
    def admin_state(self, admin_state):
        """Sets the admin_state of this Organisation.


        :param admin_state: The admin_state of this Organisation.  # noqa: E501
        :type: OrganisationStateSelector
        """

        self._admin_state = admin_state

    @property
    def status(self):
        """Gets the status of this Organisation.  # noqa: E501


        :return: The status of this Organisation.  # noqa: E501
        :rtype: OrganisationStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Organisation.


        :param status: The status of this Organisation.  # noqa: E501
        :type: OrganisationStatus
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Organisation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Organisation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.environment_config import EnvironmentConfig  # noqa: E501
from agilicus_api.rest import ApiException

class TestEnvironmentConfig(unittest.TestCase):
    """EnvironmentConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EnvironmentConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.environment_config.EnvironmentConfig()  # noqa: E501
        if include_optional :
            return EnvironmentConfig(
                id = '123', 
                app_id = '123', 
                environment_name = '123', 
                maintenance_org_id = '0', 
                config_type = 'configmap_mount', 
                mount_domain = '0', 
                mount_username = '0', 
                mount_password = '0', 
                mount_hostname = 'mount.example.com', 
                mount_share = '0', 
                mount_src_path = '0', 
                mount_path = '0', 
                file_store_uri = '0', 
                env_config_vars = [
                    agilicus_api.models.environment_config_var.EnvironmentConfigVar(
                        name = '_ab2a', 
                        value = '0', )
                    ]
            )
        else :
            return EnvironmentConfig(
                maintenance_org_id = '0',
                config_type = 'configmap_mount',
        )

    def testEnvironmentConfig(self):
        """Test EnvironmentConfig"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



import agilicus

from . import context
from .general_helpers import find_object
from .input_helpers import get_org_from_input_or_ctx
from .input_helpers import update_if_not_none
from .input_helpers import pop_item_if_none
from .input_helpers import build_updated_model
from .output.table import (
    column,
    mapped_column,
    metadata_column,
    spec_column,
    subtable,
    format_table,
)


def _build_updated_issuer(issuer, new_values):
    issuer_dict = issuer.to_dict()
    update_if_not_none(issuer_dict, new_values)

    # The clients aren't needed for updates
    issuer_dict.pop("clients", None)

    oidc_upstreams = issuer_dict.get("oidc_upstreams", [])
    for upstream in oidc_upstreams:
        pop_item_if_none(upstream)

    return agilicus.Issuer(**issuer_dict)


def _get_issuer(ctx, id, client, **kwargs):
    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    issuer = client.issuers_api.get_issuer(id, org_id=org_id)

    return issuer


def query(ctx, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    org_id = get_org_from_input_or_ctx(ctx, **kwargs)

    kwargs["org_id"] = org_id
    query_results = apiclient.issuers_api.list_issuers(**kwargs)
    if query_results:
        return query_results.issuer_extensions
    return


def format_issuers_for_garbage_collection(ctx, issuers):
    columns = [
        column("id"),
        column("issuer"),
        mapped_column("org_id", "org id"),
        column("enabled"),
    ]
    return format_table(ctx, issuers, columns)


def show(ctx, issuer_id, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    kwargs["org_id"] = org_id
    return _get_issuer(ctx, issuer_id, apiclient, **kwargs).to_dict()


def show_well_known(ctx, issuer_id, **kwargs):
    apiclient = context.get_apiclient_from_ctx(ctx)
    kwargs["org_id"] = get_org_from_input_or_ctx(ctx, **kwargs)
    return apiclient.issuers_api.get_wellknown_issuer_info(issuer_id, **kwargs).to_dict()


def format_well_known_issuer_info(ctx, info):
    columns = [
        column("issuer_id"),
        column("supported_mfa_methods"),
    ]
    return format_table(ctx, info, columns)


def list_well_known(ctx, **kwargs):
    apiclient = context.get_apiclient_from_ctx(ctx)
    kwargs["org_id"] = get_org_from_input_or_ctx(ctx, **kwargs)
    return apiclient.issuers_api.list_wellknown_issuer_info(**kwargs).well_known_info


def add(ctx, issuer, org_id, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    issuer_model = agilicus.Issuer(issuer=issuer, org_id=org_id)
    return apiclient.issuers_api.create_issuer(issuer_model).to_dict()


def _update_issuer(ctx, issuer_id, updater, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    issuer = _get_issuer(ctx, issuer_id, apiclient, **kwargs)

    if not issuer:
        print(f"Cannot find issuer {issuer_id}")
        return

    issuer = _build_updated_issuer(issuer, kwargs)

    return updater(apiclient.issuers_api, issuer_id, issuer).to_dict()


def update_root(ctx, issuer_id, **kwargs):
    return _update_issuer(ctx, issuer_id, agilicus.IssuersApi.replace_root, **kwargs)


def update_extension(ctx, issuer_id, **kwargs):
    return _update_issuer(ctx, issuer_id, agilicus.IssuersApi.replace_issuer, **kwargs)


def delete(ctx, issuer_id, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    return apiclient.issuers_api.delete_root(issuer_id, **kwargs)


def update_managed_upstreams(ctx, issuer_id, name, status, org_id=None, **kwargs):
    token = context.get_token(ctx)
    org_id = get_org_from_input_or_ctx(ctx, org_id=org_id)
    apiclient = context.get_apiclient(ctx, token)
    issuer = _get_issuer(ctx, issuer_id, apiclient, org_id=org_id, **kwargs)

    if not issuer:
        print(f"Cannot find issuer {issuer_id}")
        return

    for upstream in issuer.managed_upstreams:
        if upstream.name == name:
            upstream.enabled = status
            return apiclient.issuers_api.replace_issuer(
                issuer_id, issuer, **kwargs
            ).to_dict()
    print(f"{name} is not a managed upstream. Options are:")
    print([x.name for x in issuer.managed_upstreams])
    return


def update_oidc_upstreams(
    ctx,
    issuer_id,
    name,
    icon,
    issuer_uri,
    client_id,
    client_secret,
    issuer_external_host,
    username_key,
    user_id_key,
    email_key,
    email_verification_required,
    request_user_info,
    auto_create_status,
    **kwargs,
):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    org_id = kwargs.pop("org_id", None)
    issuer = _get_issuer(ctx, issuer_id, apiclient, org_id=org_id, **kwargs)

    if not issuer:
        print(f"Cannot find issuer {issuer_id}")
        return

    for upstream in issuer.oidc_upstreams:
        if upstream.name == name:
            if icon is not None:
                upstream.icon = icon
            if issuer_uri is not None:
                upstream.issuer = issuer_uri
            if client_id is not None:
                upstream.client_id = client_id
            if client_secret is not None:
                upstream.client_secret = client_secret
            if issuer_external_host is not None:
                upstream.issuer_external_host = issuer_external_host
            if username_key is not None:
                upstream.username_key = username_key
            if user_id_key is not None:
                upstream.user_id_key = user_id_key
            if email_key is not None:
                upstream.email_key = email_key
            if email_verification_required is not None:
                upstream.email_verification_required = email_verification_required
            if request_user_info is not None:
                upstream.request_user_info = request_user_info
            if auto_create_status is not None:
                upstream.auto_create_status = auto_create_status
            return apiclient.issuers_api.replace_issuer(
                issuer_id, issuer, **kwargs
            ).to_dict()
    print(f"{name} is not an oidc upstream")
    return


def add_oidc_upstreams(
    ctx,
    issuer_id,
    name,
    icon,
    issuer_uri,
    client_id,
    client_secret,
    issuer_external_host,
    username_key,
    user_id_key,
    email_key,
    email_verification_required,
    request_user_info,
    auto_create_status,
    **kwargs,
):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    issuer = _get_issuer(ctx, issuer_id, apiclient, **kwargs)

    if not issuer:
        print(f"Cannot find issuer {issuer_id}")
        return

    upstream = agilicus.OIDCUpstreamIdentityProvider(
        name,
        icon,
        issuer_uri,
        client_id,
        client_secret,
        issuer_external_host,
        username_key,
        email_key,
        email_verification_required,
        request_user_info,
        user_id_key,
        auto_create_status,
    )
    issuer.oidc_upstreams.append(upstream)
    kwargs.pop("org_id", None)
    return apiclient.issuers_api.replace_issuer(issuer_id, issuer, **kwargs).to_dict()


def delete_oidc_upstreams(ctx, issuer_id, name, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    kwargs.pop("org_id", None)
    issuer = _get_issuer(ctx, issuer_id, apiclient, org_id=org_id, **kwargs)

    if not issuer:
        print(f"Cannot find issuer {issuer_id}")
        return

    for upstream in issuer.oidc_upstreams:
        if upstream.name == name:
            issuer.oidc_upstreams.remove(upstream)
            apiclient.issuers_api.replace_issuer(issuer_id, issuer, **kwargs)
            return

    print(f"{name} is not an oidc upstream")
    return


def query_clients(ctx, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    kwargs["org_id"] = org_id
    query_results = apiclient.issuers_api.list_clients(**kwargs)
    if query_results:
        return query_results.clients
    return


def show_client(ctx, client_id, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    kwargs["org_id"] = org_id
    return apiclient.issuers_api.get_client(client_id, **kwargs).to_dict()


def _get_metadata_contents(metadata_file, metadata_text):
    if metadata_text is not None:
        return metadata_text

    if not metadata_file:
        return None

    with open(metadata_file, "r") as metadata_input:
        return metadata_input.read()


def add_client(
    ctx,
    issuer_id,
    name,
    metadata_file,
    metadata_text,
    **kwargs,
):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    kwargs["org_id"] = org_id
    client_model = agilicus.IssuerClient(issuer_id=issuer_id, name=name, **kwargs)
    client_model.saml_metadata_file = _get_metadata_contents(
        metadata_file, metadata_text
    )
    return apiclient.issuers_api.create_client(client_model).to_dict()


def _get_client(ctx, apiclient, client_id, **kwargs):
    apiclient = context.get_apiclient(ctx)
    org_id = get_org_from_input_or_ctx(ctx, **kwargs)

    client = apiclient.issuers_api.get_client(client_id, org_id=org_id)

    # Note: the api raises a 404 if it's not found

    return client


def update_client(
    ctx,
    client_id,
    metadata_file,
    metadata_text,
    **kwargs,
):
    apiclient = context.get_apiclient(ctx)
    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    kwargs["org_id"] = org_id
    client = _get_client(ctx, apiclient, client_id, **kwargs)

    client_dict = client.to_dict()
    update_if_not_none(client_dict, kwargs)
    client_model = agilicus.IssuerClient(**client_dict)
    client_model.saml_metadata_file = _get_metadata_contents(
        metadata_file, metadata_text
    )
    return apiclient.issuers_api.replace_client(client_id, client_model).to_dict()


def delete_client(ctx, client_id, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    kwargs["org_id"] = org_id
    return apiclient.issuers_api.delete_client(client_id, **kwargs)


def _add_to_client_list_and_replace(ctx, client_id, list_name, value, **kwargs):
    apiclient = context.get_apiclient(ctx)

    client = _get_client(ctx, apiclient, client_id, **kwargs)
    items = getattr(client, list_name) or []
    if value in items:
        return client.to_dict()

    items.append(value)
    setattr(client, list_name, items)
    return apiclient.issuers_api.replace_client(client.id, client).to_dict()


def _remove_from_client_list_and_replace(ctx, client_id, list_name, value, **kwargs):
    apiclient = context.get_apiclient(ctx)

    client = _get_client(ctx, apiclient, client_id, **kwargs)
    items = getattr(client, list_name) or []
    if value not in items:
        return client.to_dict()

    items.remove(value)
    setattr(client, list_name, items)
    return apiclient.issuers_api.replace_client(client.id, client).to_dict()


def add_redirect(ctx, client_id, redirect_url, **kwargs):
    return _add_to_client_list_and_replace(
        ctx, client_id, "redirects", redirect_url, **kwargs
    )


def delete_redirect(ctx, client_id, redirect_url, **kwargs):
    return _remove_from_client_list_and_replace(
        ctx, client_id, "redirects", redirect_url, **kwargs
    )


def add_restricted_organisation(ctx, client_id, restricted_org_id, **kwargs):
    return _add_to_client_list_and_replace(
        ctx, client_id, "restricted_organisations", restricted_org_id, **kwargs
    )


def delete_restricted_organisation(ctx, client_id, restricted_org_id, **kwargs):
    return _remove_from_client_list_and_replace(
        ctx, client_id, "restricted_organisations", restricted_org_id, **kwargs
    )


def format_policy_table(ctx, policies):
    conditions_column = [
        column("condition_type"),
        column("operator"),
        column("field"),
        column("value"),
        column("input_is_list"),
    ]
    rules_columns = [
        metadata_column("id"),
        spec_column("action"),
        spec_column("name"),
        subtable(ctx, "conditions", conditions_column, subobject_name="spec"),
    ]
    columns = [
        metadata_column("id"),
        spec_column("name"),
        spec_column("issuer_id"),
        spec_column("org_id"),
        spec_column("supported_mfa_methods"),
        spec_column("default_action"),
        subtable(ctx, "rules", rules_columns, subobject_name="spec"),
    ]
    return format_table(ctx, policies, columns)


def format_policy_rules_table(ctx, policies):
    conditions_column = [
        column("condition_type"),
        column("operator"),
        column("field"),
        column("value"),
        column("input_is_list"),
    ]
    rules_columns = [
        metadata_column("id"),
        spec_column("action"),
        subtable(ctx, "conditions", conditions_column, subobject_name="spec"),
    ]
    groups_columns = [
        metadata_column("id"),
        spec_column("name"),
        spec_column("rule_ids"),
    ]
    columns = [
        metadata_column("id"),
        spec_column("default_action"),
        subtable(ctx, "rules", rules_columns, subobject_name="spec"),
        subtable(ctx, "policy_groups", groups_columns, subobject_name="spec"),
    ]
    return format_table(ctx, policies, columns)


def list_auth_policies(ctx, **kwargs):
    apiclient = context.get_apiclient_from_ctx(ctx)
    kwargs["org_id"] = get_org_from_input_or_ctx(ctx, **kwargs)
    query_results = apiclient.issuers_api.list_policies(**kwargs)
    return query_results.authentication_policies


def add_auth_policy(ctx, issuer_id, default_action, supported_mfa_methods, **kwargs):
    apiclient = context.get_apiclient_from_ctx(ctx)
    kwargs["org_id"] = get_org_from_input_or_ctx(ctx, **kwargs)
    spec = agilicus.PolicySpec(
        issuer_id=issuer_id,
        default_action=default_action,
        supported_mfa_methods=[*supported_mfa_methods],
        **kwargs,
    )
    model = agilicus.Policy(spec=spec)
    return apiclient.issuers_api.create_policy(model).to_dict()


def update_auth_policy(ctx, policy_id, **kwargs):
    apiclient = context.get_apiclient_from_ctx(ctx)
    kwargs["org_id"] = get_org_from_input_or_ctx(ctx, **kwargs)
    policy = _get_auth_policy(apiclient, policy_id, kwargs["org_id"])
    policy.spec = build_updated_model(agilicus.PolicySpec, policy.spec, kwargs)
    for rule in policy.spec.rules:
        for condition in rule["spec"].get("conditions", []):
            pop_item_if_none(condition)
    return apiclient.issuers_api.replace_policy(policy_id, policy).to_dict()


def _get_auth_policy(apiclient, policy_id, org_id):
    return apiclient.issuers_api.get_policy(policy_id, org_id=org_id)


def get_auth_policy(ctx, policy_id, **kwargs):
    apiclient = context.get_apiclient_from_ctx(ctx)
    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    return _get_auth_policy(apiclient, policy_id, org_id).to_dict()


def delete_auth_policy(ctx, policy_id, **kwargs):
    apiclient = context.get_apiclient_from_ctx(ctx)
    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    return apiclient.issuers_api.delete_policy(policy_id, org_id=org_id)


# Rules


def add_auth_policy_rule(ctx, policy_id, action, **kwargs):
    apiclient = context.get_apiclient_from_ctx(ctx)
    kwargs["org_id"] = get_org_from_input_or_ctx(ctx, **kwargs)
    spec = agilicus.PolicyRuleSpec(action=action, conditions=[], **kwargs)
    model = agilicus.PolicyRule(spec=spec)
    return apiclient.issuers_api.create_policy_rule(policy_id, model).to_dict()


def update_auth_policy_rule(ctx, policy_id, policy_rule_id, **kwargs):
    apiclient = context.get_apiclient_from_ctx(ctx)
    kwargs["org_id"] = get_org_from_input_or_ctx(ctx, **kwargs)
    policy_rule = _get_auth_policy_rule(
        apiclient, policy_id, policy_rule_id, kwargs["org_id"]
    )
    policy_rule.spec = build_updated_model(
        agilicus.PolicyRuleSpec, policy_rule.spec, kwargs
    )

    for condition in policy_rule.spec.conditions or []:
        pop_item_if_none(condition)

    return apiclient.issuers_api.replace_policy_rule(
        policy_id, policy_rule_id, policy_rule
    ).to_dict()


def _get_auth_policy_rule(apiclient, policy_id, policy_rule_id, org_id):
    return apiclient.issuers_api.get_policy_rule(
        policy_id, policy_rule_id, org_id=org_id
    )


def get_auth_policy_rule(ctx, policy_id, policy_rule_id, **kwargs):
    apiclient = context.get_apiclient_from_ctx(ctx)
    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    return _get_auth_policy_rule(apiclient, policy_id, policy_rule_id, org_id).to_dict()


def delete_auth_policy_rule(ctx, policy_id, policy_rule_id, **kwargs):
    apiclient = context.get_apiclient_from_ctx(ctx)
    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    return apiclient.issuers_api.delete_policy_rule(
        policy_id, policy_rule_id, org_id=org_id
    )


def convert_condition_list_to_dict(conditions):
    retval = {}
    for index, cond in enumerate(conditions):
        retval[cond.condition_type] = index
    return retval


def add_auth_policy_condition(ctx, policy_id, policy_rule_id, condition_type, **kwargs):
    apiclient = context.get_apiclient_from_ctx(ctx)
    kwargs["org_id"] = get_org_from_input_or_ctx(ctx, **kwargs)
    policy_rule = _get_auth_policy_rule(
        apiclient, policy_id, policy_rule_id, kwargs["org_id"]
    )
    kwargs.pop("org_id", None)

    condition_dict = convert_condition_list_to_dict(policy_rule.spec.conditions)
    index = condition_dict.get(condition_type, None)
    if index is not None:
        policy_rule.spec.conditions[index] = build_updated_model(
            agilicus.PolicyCondition, policy_rule.spec.conditions[index], kwargs
        )
    else:
        new_cond = agilicus.PolicyCondition(condition_type=condition_type, **kwargs)
        policy_rule.spec.conditions.append(new_cond)

    return apiclient.issuers_api.replace_policy_rule(
        policy_id, policy_rule_id, policy_rule
    ).to_dict()


def delete_auth_policy_condition(
    ctx, policy_id, policy_rule_id, condition_type, **kwargs
):
    apiclient = context.get_apiclient_from_ctx(ctx)
    kwargs["org_id"] = get_org_from_input_or_ctx(ctx, **kwargs)
    policy_rule = _get_auth_policy_rule(
        apiclient, policy_id, policy_rule_id, kwargs["org_id"]
    )
    for cond in policy_rule.spec.conditions:
        if cond.condition_type == condition_type:
            policy_rule.spec.conditions.remove(cond)
            return apiclient.issuers_api.replace_policy_rule(
                policy_id, policy_rule_id, policy_rule
            ).to_dict()
    return None


def add_auth_policy_group(ctx, policy_id, **kwargs):
    apiclient = context.get_apiclient_from_ctx(ctx)
    kwargs["org_id"] = get_org_from_input_or_ctx(ctx, **kwargs)
    policy = _get_auth_policy(apiclient, policy_id, kwargs["org_id"])
    insertion_index = kwargs.pop("insertion_index", None)
    if insertion_index is None or insertion_index < 0:
        insertion_index = len(policy.spec.policy_groups)

    kwargs.pop("org_id")
    group_spec = agilicus.PolicyGroupSpec(**kwargs)
    policy.spec.policy_groups.insert(
        insertion_index, agilicus.PolicyGroup(spec=group_spec)
    )
    return apiclient.issuers_api.replace_policy(policy_id, policy).to_dict()


def delete_auth_policy_group(ctx, policy_id, policy_group_id, **kwargs):
    apiclient = context.get_apiclient_from_ctx(ctx)
    kwargs["org_id"] = get_org_from_input_or_ctx(ctx, **kwargs)
    policy = _get_auth_policy(apiclient, policy_id, kwargs["org_id"])
    for group in policy.spec.policy_groups:
        if group.metadata.id == policy_group_id:
            policy.spec.policy_groups.remove(group)
            return apiclient.issuers_api.replace_policy(policy_id, policy).to_dict()
    # ID not found return original object
    return policy.to_dict()


def format_attributes(ctx, attributes):
    columns = [
        column("attribute_name"),
        mapped_column("internal_attribute_path", "attribute_path"),
    ]
    return format_table(ctx, attributes, columns)


def set_attribute_mapping(
    ctx,
    client_id,
    attribute_name,
    attribute_path,
    **kwargs,
):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    kwargs["org_id"] = get_org_from_input_or_ctx(ctx, **kwargs)
    client = _get_client(ctx, apiclient, client_id, **kwargs)
    attributes = client.attributes
    attr = find_object(attributes, "attribute_name", attribute_name)
    if not attr:
        attr = agilicus.AuthenticationAttribute(
            attribute_name=attribute_name, internal_attribute_path=attribute_path
        )
    else:
        attributes.remove(attr)
        attr.internal_attribute_path = attribute_path

    attributes.append(attr)

    return apiclient.issuers_api.replace_client(client.id, client).attributes


def delete_attribute_mapping(
    ctx,
    client_id,
    attribute_name,
    **kwargs,
):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    kwargs["org_id"] = get_org_from_input_or_ctx(ctx, **kwargs)
    client = _get_client(ctx, apiclient, client_id, **kwargs)
    attributes = client.attributes
    attr = find_object(attributes, "attribute_name", attribute_name)
    if not attr:
        return client.attributes

    attributes.remove(attr)
    return apiclient.issuers_api.replace_client(client.id, client).attributes



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.environment_status import EnvironmentStatus  # noqa: E501
from agilicus_api.rest import ApiException

class TestEnvironmentStatus(unittest.TestCase):
    """EnvironmentStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EnvironmentStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.environment_status.EnvironmentStatus()  # noqa: E501
        if include_optional :
            return EnvironmentStatus(
                runtime_status = agilicus_api.models.runtime_status.RuntimeStatus(
                    overall_status = 'good', 
                    running_replicas = 2, 
                    error_message = 'CrashLoopBackoff', 
                    restarts = 5, 
                    cpu = 0.6, 
                    memory = 45.2, 
                    last_apply_time = '2002-10-02T10:00-05:00', 
                    updated = '2015-07-07T15:49:51.230+02:00', 
                    running_image = 'cr.agilicus.com/applications/iomad:v1.13.0', 
                    running_hash = 'sha256:2fb759c1adfe40863b89a4076111af8f210e7342d2240f09b08fc445b357112e', 
                    org_id = '123', )
            )
        else :
            return EnvironmentStatus(
        )

    def testEnvironmentStatus(self):
        """Test EnvironmentStatus"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class OrganisationAdmin(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'issuer': 'str',
        'organisation': 'str',
        'subdomain': 'str',
        'parent_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'issuer': 'issuer',
        'organisation': 'organisation',
        'subdomain': 'subdomain',
        'parent_id': 'parent_id'
    }

    def __init__(self, id=None, issuer=None, organisation=None, subdomain=None, parent_id=None, local_vars_configuration=None):  # noqa: E501
        """OrganisationAdmin - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._issuer = None
        self._organisation = None
        self._subdomain = None
        self._parent_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if issuer is not None:
            self.issuer = issuer
        self.organisation = organisation
        if subdomain is not None:
            self.subdomain = subdomain
        if parent_id is not None:
            self.parent_id = parent_id

    @property
    def id(self):
        """Gets the id of this OrganisationAdmin.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The id of this OrganisationAdmin.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrganisationAdmin.

        Unique identifier  # noqa: E501

        :param id: The id of this OrganisationAdmin.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def issuer(self):
        """Gets the issuer of this OrganisationAdmin.  # noqa: E501

        connect id issuer  # noqa: E501

        :return: The issuer of this OrganisationAdmin.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this OrganisationAdmin.

        connect id issuer  # noqa: E501

        :param issuer: The issuer of this OrganisationAdmin.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                issuer is not None and len(issuer) > 100):
            raise ValueError("Invalid value for `issuer`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                issuer is not None and len(issuer) < 1):
            raise ValueError("Invalid value for `issuer`, length must be greater than or equal to `1`")  # noqa: E501

        self._issuer = issuer

    @property
    def organisation(self):
        """Gets the organisation of this OrganisationAdmin.  # noqa: E501

        organisation name  # noqa: E501

        :return: The organisation of this OrganisationAdmin.  # noqa: E501
        :rtype: str
        """
        return self._organisation

    @organisation.setter
    def organisation(self, organisation):
        """Sets the organisation of this OrganisationAdmin.

        organisation name  # noqa: E501

        :param organisation: The organisation of this OrganisationAdmin.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and organisation is None:  # noqa: E501
            raise ValueError("Invalid value for `organisation`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                organisation is not None and len(organisation) > 100):
            raise ValueError("Invalid value for `organisation`, length must be less than or equal to `100`")  # noqa: E501

        self._organisation = organisation

    @property
    def subdomain(self):
        """Gets the subdomain of this OrganisationAdmin.  # noqa: E501

        organisation subdomain  # noqa: E501

        :return: The subdomain of this OrganisationAdmin.  # noqa: E501
        :rtype: str
        """
        return self._subdomain

    @subdomain.setter
    def subdomain(self, subdomain):
        """Sets the subdomain of this OrganisationAdmin.

        organisation subdomain  # noqa: E501

        :param subdomain: The subdomain of this OrganisationAdmin.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                subdomain is not None and len(subdomain) > 255):
            raise ValueError("Invalid value for `subdomain`, length must be less than or equal to `255`")  # noqa: E501

        self._subdomain = subdomain

    @property
    def parent_id(self):
        """Gets the parent_id of this OrganisationAdmin.  # noqa: E501

        parent organisation id  # noqa: E501

        :return: The parent_id of this OrganisationAdmin.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this OrganisationAdmin.

        parent organisation id  # noqa: E501

        :param parent_id: The parent_id of this OrganisationAdmin.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrganisationAdmin):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrganisationAdmin):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class CreateTokenRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'sub': 'str',
        'org': 'str',
        'roles': 'dict(str, str)',
        'audiences': 'list[str]',
        'time_validity': 'TimeValidity',
        'hosts': 'list[HostPermissions]',
        'token_validity': 'TokenValidity',
        'session': 'str',
        'scopes': 'list[str]'
    }

    attribute_map = {
        'sub': 'sub',
        'org': 'org',
        'roles': 'roles',
        'audiences': 'audiences',
        'time_validity': 'time_validity',
        'hosts': 'hosts',
        'token_validity': 'token_validity',
        'session': 'session',
        'scopes': 'scopes'
    }

    def __init__(self, sub=None, org=None, roles=None, audiences=None, time_validity=None, hosts=None, token_validity=None, session=None, scopes=None, local_vars_configuration=None):  # noqa: E501
        """CreateTokenRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._sub = None
        self._org = None
        self._roles = None
        self._audiences = None
        self._time_validity = None
        self._hosts = None
        self._token_validity = None
        self._session = None
        self._scopes = None
        self.discriminator = None

        self.sub = sub
        self.org = org
        if roles is not None:
            self.roles = roles
        self.audiences = audiences
        self.time_validity = time_validity
        if hosts is not None:
            self.hosts = hosts
        if token_validity is not None:
            self.token_validity = token_validity
        if session is not None:
            self.session = session
        if scopes is not None:
            self.scopes = scopes

    @property
    def sub(self):
        """Gets the sub of this CreateTokenRequest.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The sub of this CreateTokenRequest.  # noqa: E501
        :rtype: str
        """
        return self._sub

    @sub.setter
    def sub(self, sub):
        """Sets the sub of this CreateTokenRequest.

        Unique identifier  # noqa: E501

        :param sub: The sub of this CreateTokenRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and sub is None:  # noqa: E501
            raise ValueError("Invalid value for `sub`, must not be `None`")  # noqa: E501

        self._sub = sub

    @property
    def org(self):
        """Gets the org of this CreateTokenRequest.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The org of this CreateTokenRequest.  # noqa: E501
        :rtype: str
        """
        return self._org

    @org.setter
    def org(self, org):
        """Sets the org of this CreateTokenRequest.

        Unique identifier  # noqa: E501

        :param org: The org of this CreateTokenRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org is None:  # noqa: E501
            raise ValueError("Invalid value for `org`, must not be `None`")  # noqa: E501

        self._org = org

    @property
    def roles(self):
        """Gets the roles of this CreateTokenRequest.  # noqa: E501

        associative mapping of an application to a role  # noqa: E501

        :return: The roles of this CreateTokenRequest.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this CreateTokenRequest.

        associative mapping of an application to a role  # noqa: E501

        :param roles: The roles of this CreateTokenRequest.  # noqa: E501
        :type: dict(str, str)
        """

        self._roles = roles

    @property
    def audiences(self):
        """Gets the audiences of this CreateTokenRequest.  # noqa: E501

        array of audiences  # noqa: E501

        :return: The audiences of this CreateTokenRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._audiences

    @audiences.setter
    def audiences(self, audiences):
        """Sets the audiences of this CreateTokenRequest.

        array of audiences  # noqa: E501

        :param audiences: The audiences of this CreateTokenRequest.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and audiences is None:  # noqa: E501
            raise ValueError("Invalid value for `audiences`, must not be `None`")  # noqa: E501

        self._audiences = audiences

    @property
    def time_validity(self):
        """Gets the time_validity of this CreateTokenRequest.  # noqa: E501


        :return: The time_validity of this CreateTokenRequest.  # noqa: E501
        :rtype: TimeValidity
        """
        return self._time_validity

    @time_validity.setter
    def time_validity(self, time_validity):
        """Sets the time_validity of this CreateTokenRequest.


        :param time_validity: The time_validity of this CreateTokenRequest.  # noqa: E501
        :type: TimeValidity
        """
        if self.local_vars_configuration.client_side_validation and time_validity is None:  # noqa: E501
            raise ValueError("Invalid value for `time_validity`, must not be `None`")  # noqa: E501

        self._time_validity = time_validity

    @property
    def hosts(self):
        """Gets the hosts of this CreateTokenRequest.  # noqa: E501

        array of valid hosts  # noqa: E501

        :return: The hosts of this CreateTokenRequest.  # noqa: E501
        :rtype: list[HostPermissions]
        """
        return self._hosts

    @hosts.setter
    def hosts(self, hosts):
        """Sets the hosts of this CreateTokenRequest.

        array of valid hosts  # noqa: E501

        :param hosts: The hosts of this CreateTokenRequest.  # noqa: E501
        :type: list[HostPermissions]
        """

        self._hosts = hosts

    @property
    def token_validity(self):
        """Gets the token_validity of this CreateTokenRequest.  # noqa: E501


        :return: The token_validity of this CreateTokenRequest.  # noqa: E501
        :rtype: TokenValidity
        """
        return self._token_validity

    @token_validity.setter
    def token_validity(self, token_validity):
        """Sets the token_validity of this CreateTokenRequest.


        :param token_validity: The token_validity of this CreateTokenRequest.  # noqa: E501
        :type: TokenValidity
        """

        self._token_validity = token_validity

    @property
    def session(self):
        """Gets the session of this CreateTokenRequest.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The session of this CreateTokenRequest.  # noqa: E501
        :rtype: str
        """
        return self._session

    @session.setter
    def session(self, session):
        """Sets the session of this CreateTokenRequest.

        Unique identifier  # noqa: E501

        :param session: The session of this CreateTokenRequest.  # noqa: E501
        :type: str
        """

        self._session = session

    @property
    def scopes(self):
        """Gets the scopes of this CreateTokenRequest.  # noqa: E501

        The list of scopes requested for the access token. Multiple scopes are seperated by a space character. Ex. urn:agilicus:users urn:agilicus:issuers. An optional is specified with an ? at the end. Optional scopes are used when the permission is requested but not required. Ex. urn:agilicus:users?  # noqa: E501

        :return: The scopes of this CreateTokenRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._scopes

    @scopes.setter
    def scopes(self, scopes):
        """Sets the scopes of this CreateTokenRequest.

        The list of scopes requested for the access token. Multiple scopes are seperated by a space character. Ex. urn:agilicus:users urn:agilicus:issuers. An optional is specified with an ? at the end. Optional scopes are used when the permission is requested but not required. Ex. urn:agilicus:users?  # noqa: E501

        :param scopes: The scopes of this CreateTokenRequest.  # noqa: E501
        :type: list[str]
        """

        self._scopes = scopes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateTokenRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateTokenRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class FeatureFlag(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'feature': 'str',
        'enabled': 'bool',
        'setting': 'str'
    }

    attribute_map = {
        'feature': 'feature',
        'enabled': 'enabled',
        'setting': 'setting'
    }

    def __init__(self, feature=None, enabled=None, setting='', local_vars_configuration=None):  # noqa: E501
        """FeatureFlag - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._feature = None
        self._enabled = None
        self._setting = None
        self.discriminator = None

        self.feature = feature
        self.enabled = enabled
        if setting is not None:
            self.setting = setting

    @property
    def feature(self):
        """Gets the feature of this FeatureFlag.  # noqa: E501

        The name of the feature  # noqa: E501

        :return: The feature of this FeatureFlag.  # noqa: E501
        :rtype: str
        """
        return self._feature

    @feature.setter
    def feature(self, feature):
        """Sets the feature of this FeatureFlag.

        The name of the feature  # noqa: E501

        :param feature: The feature of this FeatureFlag.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and feature is None:  # noqa: E501
            raise ValueError("Invalid value for `feature`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                feature is not None and len(feature) > 128):
            raise ValueError("Invalid value for `feature`, length must be less than or equal to `128`")  # noqa: E501

        self._feature = feature

    @property
    def enabled(self):
        """Gets the enabled of this FeatureFlag.  # noqa: E501

        Whether the feature is enabled  # noqa: E501

        :return: The enabled of this FeatureFlag.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this FeatureFlag.

        Whether the feature is enabled  # noqa: E501

        :param enabled: The enabled of this FeatureFlag.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `enabled`, must not be `None`")  # noqa: E501

        self._enabled = enabled

    @property
    def setting(self):
        """Gets the setting of this FeatureFlag.  # noqa: E501

        a specific setting for the feature  # noqa: E501

        :return: The setting of this FeatureFlag.  # noqa: E501
        :rtype: str
        """
        return self._setting

    @setting.setter
    def setting(self, setting):
        """Sets the setting of this FeatureFlag.

        a specific setting for the feature  # noqa: E501

        :param setting: The setting of this FeatureFlag.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                setting is not None and len(setting) > 4096):
            raise ValueError("Invalid value for `setting`, length must be less than or equal to `4096`")  # noqa: E501

        self._setting = setting

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeatureFlag):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FeatureFlag):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'application_services': 'list[ApplicationService]',
        'service_account_id': 'str',
        'info': 'AgentConnectorInfo',
        'stats': 'AgentConnectorStats'
    }

    attribute_map = {
        'application_services': 'application_services',
        'service_account_id': 'service_account_id',
        'info': 'info',
        'stats': 'stats'
    }

    def __init__(self, application_services=None, service_account_id=None, info=None, stats=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._application_services = None
        self._service_account_id = None
        self._info = None
        self._stats = None
        self.discriminator = None

        if application_services is not None:
            self.application_services = application_services
        if service_account_id is not None:
            self.service_account_id = service_account_id
        if info is not None:
            self.info = info
        if stats is not None:
            self.stats = stats

    @property
    def application_services(self):
        """Gets the application_services of this AgentConnectorStatus.  # noqa: E501

        The list of application services associated with this agent  # noqa: E501

        :return: The application_services of this AgentConnectorStatus.  # noqa: E501
        :rtype: list[ApplicationService]
        """
        return self._application_services

    @application_services.setter
    def application_services(self, application_services):
        """Sets the application_services of this AgentConnectorStatus.

        The list of application services associated with this agent  # noqa: E501

        :param application_services: The application_services of this AgentConnectorStatus.  # noqa: E501
        :type: list[ApplicationService]
        """

        self._application_services = application_services

    @property
    def service_account_id(self):
        """Gets the service_account_id of this AgentConnectorStatus.  # noqa: E501

        Service account user GUID used to deploy the connector  # noqa: E501

        :return: The service_account_id of this AgentConnectorStatus.  # noqa: E501
        :rtype: str
        """
        return self._service_account_id

    @service_account_id.setter
    def service_account_id(self, service_account_id):
        """Sets the service_account_id of this AgentConnectorStatus.

        Service account user GUID used to deploy the connector  # noqa: E501

        :param service_account_id: The service_account_id of this AgentConnectorStatus.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                service_account_id is not None and len(service_account_id) > 40):
            raise ValueError("Invalid value for `service_account_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                service_account_id is not None and len(service_account_id) < 1):
            raise ValueError("Invalid value for `service_account_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._service_account_id = service_account_id

    @property
    def info(self):
        """Gets the info of this AgentConnectorStatus.  # noqa: E501


        :return: The info of this AgentConnectorStatus.  # noqa: E501
        :rtype: AgentConnectorInfo
        """
        return self._info

    @info.setter
    def info(self, info):
        """Sets the info of this AgentConnectorStatus.


        :param info: The info of this AgentConnectorStatus.  # noqa: E501
        :type: AgentConnectorInfo
        """

        self._info = info

    @property
    def stats(self):
        """Gets the stats of this AgentConnectorStatus.  # noqa: E501


        :return: The stats of this AgentConnectorStatus.  # noqa: E501
        :rtype: AgentConnectorStats
        """
        return self._stats

    @stats.setter
    def stats(self, stats):
        """Sets the stats of this AgentConnectorStatus.


        :param stats: The stats of this AgentConnectorStatus.  # noqa: E501
        :type: AgentConnectorStats
        """

        self._stats = stats

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorStatus):
            return True

        return self.to_dict() != other.to_dict()
